@@ -3,16 +3,18 @@
 from . import logging_tools
 from .enviro_tools import from_environment, from_environment_as_dataclass  # noqa
 from .setup_tools import SetupShop  # noqa
+from .strtobool import strtobool
 
 __all__ = [
     "from_environment",
     "from_environment_as_dataclass",
     "SetupShop",
     "logging_tools",
+    "strtobool",
 ]
 
 # version is a human-readable version number.
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 # version_info is a four-tuple for programmatic comparison. The first
 # three numbers are the components of the version number. The fourth
